<template>
 <v-dialog
    persistent
        v-model="show"
        max-width="650px"
        transition="dialog-bottom-transition"
        scrollable
      >
        <v-card tile>
          <v-toolbar card color="#fff">
            <v-btn icon to="/" dark @click.native="show = false">
              <v-icon>arrow_back</v-icon>
            </v-btn>
            <v-toolbar-title v-if="forgot_password">Forgot Password</v-toolbar-title>
            <v-toolbar-title v-else>Login</v-toolbar-title>
            <v-spacer></v-spacer>
            <v-toolbar-items>
              <!-- <v-btn dark flat @click.native="addnew = false">Save</v-btn> -->
            </v-toolbar-items>
          </v-toolbar>
          <v-card-text>
            <div v-if="!forgot_password">
                <v-alert :value="true" type="info" outline v-if="alert_message" class="mb-20">
                    {{ alert_message }}
                </v-alert>
            </div>

            <v-form ref="form" v-model="validate">
                <v-text-field
                    label="Mobile / Email Address"
                    v-model="auth.mobile"
                    name="mobile"
                    autofocus
                    type="text"
                    class="mb-20"
                ></v-text-field>
                <div v-if="forgot_password" class="mb-20">
                    <v-text-field
                        label="Enter OTP"
                        type="tel"
                        :rules="validateRule"
                        v-model="auth.fp_otp"
                        persistent-hint
                        hint="Code will be sent on given mobile number"
                        class="mb-20"
                    ></v-text-field>
                    <v-text-field
                        label="New Password"
                        type="password"
                        :rules="validateRule"
                        v-model="auth.fp_password"
                    ></v-text-field>
                    <v-btn
                        @click="forgotPassword"
                        class="m-0 mb-20"
                        large
                        :loading="loading"
                        block
                        color="secondary"
                        type="button"
                        name="auth_login"
                    >Forgot Password</v-btn>
                </div>
                <div v-else>
                    <div class="relative _dg">
                        <v-text-field
                            label="Password"
                            v-model="auth.password"
                            hint="Min. 6 character"
                            name="password"
                            :rules="validateRule"
                            type="password"
                            class="mb-20"
                        >
                        </v-text-field>
                        <div class="_fp pointer" @click="forgotPasswordCheck">Forgot Password?</div>
                    </div>
                    <v-btn
                        @click="authLogin"
                        class="m-0 mb-20"
                        large
                        :loading="loading"
                        block
                        color="secondary"
                        type="button"
                        name="auth_login"
                    >Login</v-btn>
                </div>
                <div v-if="forgot_password">
                    <v-btn
                        @click="loginScreen"
                        class="m-0 mb-20"
                        large
                        block
                        color="secondary"
                        type="button"
                        outline
                        name="auth_login"
                    > Back to Login</v-btn>
                </div>
                <p class="_auth_desc" v-if="!forgot_password">
                    Creating an account is fast, easy, and free. You'll be able to manage your autoships, track your orders, write reviews, and more!
                </p>
                <v-btn
                 outline
                 color="secondary"
                 block
                 :to="getToLink()"
                 v-if="!forgot_password"
                >Create New Account</v-btn>
            </v-form>
          </v-card-text>
        </v-card>
      </v-dialog>
</template>

<script>
import axios from 'axios';
export default {
    props: ['show', 'alert_message', 'order'],
    data () {
        return {
            mobileMask: 'phone',
            forgot_password: false,
            validate: true,
            auth: [],
            loading: false,
            mobileRules: [
                v => !!v && v.length >= 10 || 'Mobile must be 10 digit number'
            ],
            validateRule: [
                v => !!v || 'This field is required'
            ]
        }
    },
    methods: {
        getToLink: function () {
            if (this.order) {
                return '/customer/register?back=order';
            } else {
                return '/customer/register';
            }
        },
        loginScreen: function () {
            this.forgot_password = false;
        },
        forgotPasswordCheck: function () {
            if (!this.auth.mobile) {
                this.$store.commit('showSnackBar', 'Please add mobile number to reset password');
            }
            if (this.auth.mobile) {
                if (this.auth.mobile.length < 10) {
                    this.$store.commit('showSnackBar', 'Mobile number should be of 10 digits');
                } else {
                    this.forgot_password = true;
                    var form_data = new FormData();
                    form_data.append('mobile', this.auth.mobile);
                    axios.post(this.$store.state.api_domain + '?comp=process&action=sendOTP', form_data, {withCredentials: true})
                    .then((res) => {
                        this.$store.commit('showSnackBar', res.data.message);
                    });
                }
            }
        },
        forgotPassword: function () {
            if (this.$refs.form.validate()) {
                this.loading = true;
                var form_data = new FormData();
                form_data.append('mobile', this.auth.mobile);
                form_data.append('code', this.auth.fp_otp);
                form_data.append('password', this.auth.fp_password);

                axios.post(this.$store.state.api_domain + '?comp=process&action=forgot_password', form_data, {withCredentials:true}).then((res) => {
                    if (res.data.status == 'success') {
                        this.auth.fp_otp = '';
                        this.auth.fp_password = '';
                        this.$store.commit('showSnackBar', res.data.message);
                        this.forgot_password = false;
                    }

                    if (res.data.status == 'error') {
                        this.$store.commit('showSnackBar', res.data.message);
                    }
                    this.loading = false;
                });
            }

        },
        authLogin: function () {
            this.$store.commit('hideSnackBar');
            if (this.$refs.form.validate()){

                this.loading = true;
                var form_data = new FormData();
                form_data.append('mobile', this.auth.mobile);
                form_data.append('password', this.auth.password);

                axios.post(this.$store.state.api_domain + '?comp=process&action=authLogin', form_data, {withCredentials: true}).then((res) => {

                    this.loading = false;

                    if (res.data.status == 'success') {
                        this.$store.commit('showSnackBar', res.data.message);
                        var t = this;
                        this.order.checkOrderProcess();
                        setTimeout(function () {
                            t.order.login_screen = false;
                        }, 200);
                    }

                    if (res.data.status == 'error') {
                        this.$store.commit('showSnackBar', res.data.message);
                    }
                });
            }
        },
        registerHere: function () {
            this.order.register_screen = true;
            var t = this;
            setTimeout(function () {
                t.order.login_screen = false;
            }, 200);
        }
    },
    beforeCreated () {
        this.loading = false;
    }
}
</script>
